@@ -5,7 +5,7 @@ from raypyc.structures import Color
 LIGHTGRAY = Color(200, 200, 200, 255)  # Light Gray
 GRAY = Color(130, 130, 130, 255)  # Gray
 DARKGRAY = Color(80, 80, 80, 255)  # Dark Gray
-YELLO = Color(253, 249, 0, 255)  # Yellow
+YELLOW = Color(253, 249, 0, 255)  # Yellow
 Gold = Color(255, 203, 0, 255)  # Gold
 Orange = Color(255, 161, 0, 255)  # Orange
 PINK = Color(255, 109, 194, 255)  # Pink
